==> addEvents.4.0.zip: lang/fr.php <==
<?php
	$LANG = array(
	'L_PAGE_TITLE'				=> 'Evenements - rendez-vous',
	'L_DESCRIPTION'				=> 'Description',
	
	#static
	'L_INTRO_STATIC'			=> 'Toutes nos dates à ne pas rater.',
	
	#modules
	'L_CALENDAR_EVENT'			=> 'Calendrier des événements',
	'L_IT_IS_NOW'				=> 'C\'est maintenant!',
	
	# config multilingue 
	'L_DEFAULT_MENU_NAME'		=> 'addEvents',
	'L_MENU_DISPLAY'			=> 'Afficher la page static au menu',
	'L_FORM_DISPLAY'			=> 'Afficher le formulaire de recherche sur la page de recherche',
	'L_MENU_TITLE'				=> 'Titre de la page et du menu',
	'L_MENU_POS'		    	=> 'Position du menu',
	'L_TEMPLATE'				=> 'Gabari',
	'L_PARAM_URL'				=> 'Nom du paramètre dans l\'url',
	'L_ASSOCIATE_EVENT'			=> 'Permet d\'associer un article à un ou plusieurs événements.',
	'L_EVENT_INSERT_FIELD'		=> 'Insère un champs "Événement" dans l’édition, création des articles',
	'L_EVENT_INSERT_NOTE'		=> 'Insère une notification visuelle sur vos articles associés à un événement',
	'L_EVENT_CREATE_STATIC'		=> 'genére une page statique virtuelle listant vos événements par dates d\'évenements.',
	'L_#DAY'					=> 'affiche le jour (au format texte : lundi, mardi, etc…)',
	'L_#MONTH'					=> ' affiche le mois (au format texte : janvier, février, mars, etc…)',
	'L_#NUM_DAY'				=> 'affiche le numéro du jour du mois (1, 15, …, 31,)',
	'L_#NUM_MONTH'				=> 'affiche le numéro du mois (1, 2, 5, …, 12,)',
	'L_#NUM_YEAR4'				=> 'affiche l\'année sur quatre chiffres (ex: 2024)',
	'L_#NUM_YEAR2'				=> 'affiche l\'année sur deux chiffres (ex: 24)',
	'L_#FREE_VALUE'				=> 'Chaine de caractéeres de son choix.',

	#form participation
	'L_ILL_BE_THERE'			=> 'Je serais présent',
	'L_THKS_ANSWERING'			=> 'Merci pour votre reponse',
	'L_PARTICIPANTS'			=> 'Participants',
	
	#wizard
	'L_PREVIOUS'				=> 'Page précedente',
	'L_NEXT'					=> 'Page suivante',
	'L_CLOSE'					=> 'Fermer l\'aide',
	
	#config
	'L_SAVE'					=> 'enregistrer',
	'L_YES'						=> 'Oui',
	'L_MAYBE'					=> 'Peut-être',
	'L_NO'						=> 'Non',
	'L_PARAMS'					=> 'Paramètres&nbsp;',
	'L_CONFIG'					=> 'Configuration',
	'L_ADMIN'					=> 'Administration',
	'L_DATE_FORMAT'				=> 'Format d\'affichage de la date',
	'L_PARAMS_HELP'				=> 'Aide: ',
	'L_EVENT'					=> 'Date de l\'événement ',
	'L_EVENT_LAST_DAY'			=> 'jusqu\'au',
	'L_FROM'					=> 'De',
	'L_TO'						=> 'à',
	'L_EVENT_TIME_START'		=> 'Heure de début',
	'L_EVENT_TIME_END'			=> 'Heure de fin',
	'L_MAIN'					=> 'Page statique&nbsp;',
	'L_CONFIG_VIEW_STATIC'		=> '&nbsp;Tri en page static&nbsp;',
	'L_CONFIG_VIEW_PAST'		=> 'Afficher les dates passées.'
	# et ainsi de suite pour chaque mot(s) à traduire
	);

==> addEvents.4.1.0.zip: lang/fr.php <==
<?php
	$LANG = array(
	'L_PAGE_TITLE'				=> 'Evenements - rendez-vous',
	'L_DESCRIPTION'				=> 'Description',
	
	#static
	'L_INTRO_STATIC'			=> 'Toutes nos dates à ne pas rater.',
	
	#modules
	'L_CALENDAR_EVENT'			=> 'Calendrier des événements',
	'L_IT_IS_NOW'				=> 'C\'est maintenant!',
	
	# config multilingue 
	'L_DEFAULT_MENU_NAME'		=> 'addEvents',
	'L_MENU_DISPLAY'			=> 'Afficher la page static au menu',
	'L_FORM_DISPLAY'			=> 'Afficher le formulaire de recherche sur la page de recherche',
	'L_MENU_TITLE'				=> 'Titre de la page et du menu',
	'L_MENU_POS'		    	=> 'Position du menu',
	'L_TEMPLATE'				=> 'Gabari',
	'L_PARAM_URL'				=> 'Nom du paramètre dans l\'url',
	'L_ASSOCIATE_EVENT'			=> 'Permet d\'associer un article à un ou plusieurs événements.',
	'L_EVENT_INSERT_FIELD'		=> 'Insère un champs "Événement" dans l’édition, création des articles',
	'L_EVENT_INSERT_NOTE'		=> 'Insère une notification visuelle sur vos articles associés à un événement',
	'L_EVENT_CREATE_STATIC'		=> 'genére une page statique virtuelle listant vos événements par dates d\'évenements.',
	'L_#DAY'					=> 'affiche le jour (au format texte : lundi, mardi, etc…)',
	'L_#MONTH'					=> ' affiche le mois (au format texte : janvier, février, mars, etc…)',
	'L_#NUM_DAY'				=> 'affiche le numéro du jour du mois (1, 15, …, 31,)',
	'L_#NUM_MONTH'				=> 'affiche le numéro du mois (1, 2, 5, …, 12,)',
	'L_#NUM_YEAR4'				=> 'affiche l\'année sur quatre chiffres (ex: 2024)',
	'L_#NUM_YEAR2'				=> 'affiche l\'année sur deux chiffres (ex: 24)',
	'L_#FREE_VALUE'				=> 'Chaine de caractéeres de son choix.',

	#form participation
	'L_ILL_BE_THERE'			=> 'Je serais présent',
	'L_THKS_ANSWERING'			=> 'Merci pour votre reponse',
	'L_PARTICIPANTS'			=> 'Participants',
	'L_EVENTS_JOIGNIN_IN'		=> 'Tableaux des participants par évenements.',
	
	#wizard
	'L_PREVIOUS'				=> 'Page précedente',
	'L_NEXT'					=> 'Page suivante',
	'L_CLOSE'					=> 'Fermer l\'aide',
	
	#config
	'L_SAVE'					=> 'enregistrer',
	'L_YES'						=> 'Oui',
	'L_MAYBE'					=> 'Peut-être',
	'L_NO'						=> 'Non',
	'L_PARAMS'					=> 'Paramètres&nbsp;',
	'L_CONFIG'					=> 'Configuration',
	'L_ADMIN'					=> 'Administration',
	'L_DATE_FORMAT'				=> 'Format d\'affichage de la date',
	'L_PARAMS_HELP'				=> 'Aide: ',
	'L_EVENT'					=> 'Date de l\'événement ',
	'L_EVENT_LAST_DAY'			=> 'jusqu\'au',
	'L_FROM'					=> 'De',
	'L_TO'						=> 'à',
	'L_EVENT_TIME_START'		=> 'Heure de début',
	'L_EVENT_TIME_END'			=> 'Heure de fin',
	'L_MAIN'					=> 'Page statique&nbsp;',
	'L_CONFIG_VIEW_STATIC'		=> '&nbsp;Tri en page static&nbsp;',
	'L_CONFIG_VIEW_PAST'		=> 'Afficher les dates passées.',
	'L_CONFIG_VIEW_FUTUR'		=> 'Afficher les dates à venir.'
	# et ainsi de suite pour chaque mot(s) à traduire
	);
